@@ -7,16 +7,16 @@ from clime_bus_factor.args import mainArgs
 from clime_bus_factor.version import version
 
 
-def buildBusFactor(df: DataFrame, bucket: int) -> DataFrame:
+def buildBusFactor(df: DataFrame, bin: int) -> DataFrame:
     daysSince0: Series = df["author_days_since_0"].unique()
 
     data: list = []
 
-    maxDays: int = daysSince0.max() + bucket
-    bucketList: list = [day for day in range(maxDays) if day % bucket == 0]
+    maxDays: int = daysSince0.max() + bin
+    bins: list = [day for day in range(maxDays) if day % bin == 0]
 
     df["commitBin"] = pandas.cut(
-        df["author_days_since_0"], bins=bucketList, include_lowest=True
+        df["author_days_since_0"], bins=bins, include_lowest=True
     )
 
     bins: Categorical = df["commitBin"].unique()
@@ -45,12 +45,12 @@ def main() -> None:
         print(f"clime-git-bus-factor-compute version {version()}")
         quit(0)
 
-    if args.bucket < 1:
-        print(f"Bucket arguement must be an integer greater than 0: {args.bucket}")
+    if args.bin < 1:
+        print(f"Bin arguement must be an integer greater than 0: {args.bin}")
         quit(1)
 
     df: DataFrame = pandas.read_json(args.input).T
-    buildBusFactor(df, bucket=args.bucket).to_json(args.output, indent=4)
+    buildBusFactor(df, bin=args.bin).to_json(args.output, indent=4)
 
 
 if __name__ == "__main__":
